<template>
    <div class="bbsl-common-page">
        <div class="bbsl-table-search">
            <el-breadcrumb separator-class="el-icon-arrow-right">
                <el-breadcrumb-item :to="{path: '/platLayout/reportFilling'}">{{
                    $t('report.rootNode')
                }}</el-breadcrumb-item>
                <el-breadcrumb-item
                    :to="{
                        path:
                            '/platLayout/reportFillingComp?id=' +
                            this.$route.query.reportId,
                    }"
                >
                    {{
                        $i18n.locale === 'zh-CN'
                            ? this.$route.query.parentName
                            : this.$route.query.parentNameEn
                    }}</el-breadcrumb-item
                >
                <el-breadcrumb-item
                    >{{ this.$route.query.fillYear }}-{{
                        this.$route.query.fillMonth < 10 ? '0' : ''
                    }}{{ this.$route.query.fillMonth }}
                    {{ $t('report.detailNode') }}
                </el-breadcrumb-item>
            </el-breadcrumb>
        </div>
        <el-row :gutter="10" class="card-table flex">
            <el-col
                class="card-table-container"
                style="width: 100%"
                ref="contentPanel"
            >
                <div class="bbsl-btn-content" ref="btnPanel">
                    <el-button
                        icon="el-icon-plus"
                        type="primary"
                        class="btn btn-plus"
                        @click="handleSave"
                        :disabled="!hasData"
                    >
                        {{ $t('common.save') }}
                    </el-button>
                    <el-button
                        type="success"
                        icon="el-icon-upload"
                        @click="importKPL"
                        >{{ $t('common.import') }}
                    </el-button>
                    <el-button
                        type="warning"
                        icon="el-icon-download"
                        @click="exportKPL"
                    >
                        {{ $t('common.export') }}
                    </el-button>
                    <el-button type="info" icon="el-icon-download">
                        <a
                            :href="actionUrl + '/qf/finance/pl/downModel'"
                            target="_blank"
                            >{{ $t('report.downLoad') }}</a
                        >
                    </el-button>
                </div>

                <el-table
                    border
                    size="mini"
                    v-if="hasData"
                    :data="tableData"
                    v-loading="loading"
                    ref="multipleSelection"
                    :style="{width: '100%'}"
                    :max-height="tableMaxHeight"
                    :header-cell-style="{'text-align': 'center'}"
                >
                    <el-table-column
                        prop="subjectName"
                        label="subjectName"
                        min-width="200"
                        show-overflow-tooltip
                        fixed="left"
                    >
                    </el-table-column>
                    <el-table-column
                        prop="subjectCode"
                        label="subjectCode"
                        min-width="160"
                        align="center"
                        show-overflow-tooltip
                        fixed="left"
                    >
                    </el-table-column>
                    <el-table-column
                        prop="subjectUnit"
                        label="subjectUnit"
                        min-width="100"
                        align="center"
                        show-overflow-tooltip
                        fixed="left"
                    >
                    </el-table-column>
                    <el-table-column
                        v-for="(value, key) in tableHearder"
                        :key="key"
                        :prop="key"
                        :label="key"
                        min-width="120"
                        align="center"
                    >
                        <template v-slot="{row}">
                            <el-input
                                type="number"
                                v-model.trim="row[key]"
                                @change="
                                    (val) =>
                                        changeData(val, row.subjectCode, key)
                                "
                            />
                        </template>
                    </el-table-column>
                    <el-table-column
                        v-for="(item, index) in totalheader"
                        :key="item"
                        :prop="item"
                        :label="item"
                        :min-width="index == 2 ? 260 : 160"
                        align="center"
                    >
                        <template v-slot="{row}">
                            <el-input
                                type="number"
                                v-model.trim="row[item]"
                                @change="
                                    (val) =>
                                        changeData(val, row.subjectCode, item)
                                "
                            />
                        </template>
                    </el-table-column>
                </el-table>
                <el-empty
                    v-if="!loading && !hasData"
                    :description="$t('report.importTemp')"
                >
                    <el-button
                        type="success"
                        icon="el-icon-upload"
                        @click="importKPL"
                        >{{ $t('common.import') }}
                    </el-button></el-empty
                >
                <el-col ref="paginationPanel"></el-col>
            </el-col>
        </el-row>
        <!-- 导入弹框 -->
        <el-dialog
            :title="$t('common.import')"
            :visible.sync="dialogVisible"
            width="30%"
            :before-close="handleClose"
        >
            <el-upload
                class="upload-demo"
                drag
                :action="actionUrl + '/qf/finance/pl/importExcel'"
                :data="uploadData"
                :on-success="handleAvatarSuccess"
                :headers="header"
            >
                <i class="el-icon-upload"></i>
                <div class="el-upload__text">
                    {{ $t('report.importTips')
                    }}<em>{{ $t('report.importTipsLoad') }}</em>
                </div>
            </el-upload>
        </el-dialog>
    </div>
</template>

<script>
import {mapState} from 'vuex'
import {TableMixin} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import profit from '@/api/configureInfo/profit.js'
export default {
    name: 'profitDetails',
    components: {},
    mixins: [TableMixin],
    data() {
        return {
            hasData: false,
            loading: false,
            tableData: [],
            tableHearder: {}, // 表头
            multipleSelection: [],
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                },
            },
            total: 0,
            jbList: [],
            parentId: 0,
            sortList: {},
            title: '',
            id: '',
            dialogVisible: false,
            actionUrl: '',
            uploadData: {
                mainId: '',
            },
            modifyData: {},
            totalheader: [
                'Total',
                'Consolidation Posting',
                'Consolidated Financial Statement',
            ],
            totalKey: {
                Total: 'actualTotal',
                'Consolidation Posting': 'actualPosting',
                'Consolidated Financial Statement': 'actualConsolidated',
            },
        }
    },
    watch: {},

    created() {
        if (this.$i18n.locale === 'zh-CN') {
            this.jbList = dictUtils.getDictItemsFromCache('jb')
        } else {
            this.jbList = dictUtils.getDictItemsFromCache('jb_en')
        }
        this.actionUrl = window.context.portal
        console.log(this.$route.query)
        this.title = this.$route.query.name ? this.$route.query.name : '编辑'
        this.id = this.$route.query.id
        this.uploadData.mainId = this.$route.query.id
        this.title == '编辑' ? this.getData() : ''
    },
    computed: mapState({
        header: (state) => {
            return {
                Authorization: `Bearer ${state.login.currentUser.token}`,
            }
        },
    }),
    mounted() {},
    methods: {
        changeData(value, code, column) {
            if (this.modifyData[code]) {
                this.modifyData[code][column] = value
            } else {
                this.modifyData[code] = {
                    [column]: value,
                }
            }
        },
        //获取数据
        getData() {
            this.loading = true
            this.queryParam.querys = [
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'mainId',
                    relation: 'AND',
                    value: this.id,
                },
            ]

            profit.headerDetailQuery(this.queryParam, (res) => {
                console.log(res)
                if (res.state) {
                    console.log(res)
                    let length = res.value.length
                    if (length) {
                        this.hasData = true
                        this.tableHearder = res.value[0]
                        delete this.tableHearder.subjectName
                        delete this.tableHearder.subjectCode
                        delete this.tableHearder.subjectUnit
                        delete this.tableHearder.subjectLevel
                        delete this.tableHearder.Total
                        delete this.tableHearder['Consolidation Posting']
                        delete this.tableHearder[
                            'Consolidated Financial Statement'
                        ]
                        res.value.splice(0, 1)
                        this.tableData = res.value
                        let tempData = res.value
                        tempData.forEach((item) => {
                            let space = ''
                            let level = parseInt(item.subjectLevel)
                            if (level) {
                                for (let i = 1; i <= level; i++) {
                                    space += '\xa0'
                                }
                            }
                            item.subjectName = space + item.subjectName
                        })
                        this.$set(this.tableData)
                    } else {
                        this.hasData = false
                    }
                }
                this.loading = false
            })
        },

        //保存
        handleSave() {
            let keys = Object.keys(this.modifyData)
            if (!keys.length) {
                this.$message({
                    message: this.$t('report.unchanged'),
                    type: 'warning',
                })
            } else {
                // 数据提交格式组装
                // dataUpload 动态字段
                // totalListUpload 固定统计字段
                // 动态字段格式
                //   [{
                //      subjectCode:'',
                //      actualYtd:'',
                //      enterpriseCode: ''
                //    },{
                //      subjectCode:'',
                //      actualYtd:'',
                //      enterpriseCode: ''
                //  }]
                //  固定统计字段格式
                //   [{
                //      subjectCode:'',
                //      actualTotal:'',
                //      actualPosting: '',
                //      actualConsolidated:''
                //    },{
                //      subjectCode:'',
                //      actualTotal:'',
                //      actualPosting: '',
                //      actualConsolidated:''
                //  }]
                let dataUpload = []
                let totalListUpload = []
                for (let key in this.modifyData) {
                    let totalObj = {}
                    for (let valKey in this.modifyData[key]) {
                        let obj = {}
                        obj.subjectCode = key
                        if (!this.totalheader.includes(valKey)) {
                            obj.enterpriseCode = valKey
                            obj.actualYtd = this.modifyData[key][valKey]
                            dataUpload.push(obj)
                        }
                        if (this.totalheader.includes(valKey)) {
                            totalObj.subjectCode = key
                            totalObj[this.totalKey[valKey]] =
                                this.modifyData[key][valKey]
                        }
                    }
                    if (totalObj.subjectCode) {
                        totalListUpload.push(totalObj)
                    }
                }
                profit.batchUpdateData(
                    {
                        id: this.id,
                        list: dataUpload,
                        totalList: totalListUpload,
                    },
                    (res) => {
                        if (res.state) {
                            this.modifyData = {}
                            this.$notify({
                                type: 'success',
                                message: this.$t('domestic.success'),
                                duration: 2000,
                            })
                            this.getData()
                            // this.$router.go(-1)
                        }
                    }
                )
            }
        },
        handleClose() {
            this.dialogVisible = false
        },
        //导出
        exportKPL() {
            profit.export(this.queryParam, (res) => {})
        },
        //导入运营kpl数据
        importKPL() {
            if (!this.tableData.length) {
                this.dialogVisible = true
            } else {
                this.$confirm(
                    this.$t('report.importCoverTips'),
                    this.$t('common.tips'),
                    {
                        confirmButtonText: this.$t('common.confirm'),
                        cancelButtonText: this.$t('common.cancel'),
                        type: 'warning',
                    }
                )
                    .then(() => {
                        this.dialogVisible = true
                    })
                    .catch(() => {})
            }
        },
        //上传成功
        handleAvatarSuccess(res, file) {
            this.dialogVisible = false
            this.$notify({
                type: 'success',
                message: this.$t('domestic.success'),
                duration: 2000,
            })
            this.getData()
        },
    },
}
</script>

<style lang="scss" scoped>
	@import "~@/assets/css/fillDetail.scss";
</style>
